==> jc-1.4.0.tar.gz: java/security/spec/RSAPrivateKeySpec.h <==
// public class java.security.spec.RSAPrivateKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 47d1dcfa807306d7 java_security_spec_RSAPrivateKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_RSAPrivateKeySpec_H_
#define _JC_java_security_spec_RSAPrivateKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_RSAPrivateKeySpec$sub_refs	_jc_java_security_spec_RSAPrivateKeySpec$sub_refs;
typedef struct _jc_java_security_spec_RSAPrivateKeySpec$sub_nonrefs	_jc_java_security_spec_RSAPrivateKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_RSAPrivateKeySpec$refs	_jc_java_security_spec_RSAPrivateKeySpec$refs;
typedef struct _jc_java_security_spec_RSAPrivateKeySpec$nonrefs	_jc_java_security_spec_RSAPrivateKeySpec$nonrefs;
typedef struct _jc_java_security_spec_RSAPrivateKeySpec$object	_jc_java_security_spec_RSAPrivateKeySpec$object;

typedef const struct _jc_java_security_spec_RSAPrivateKeySpec$vmethods	_jc_java_security_spec_RSAPrivateKeySpec$vmethods;
typedef const struct _jc_java_security_spec_RSAPrivateKeySpec$vtable	_jc_java_security_spec_RSAPrivateKeySpec$vtable;
typedef const struct _jc_java_security_spec_RSAPrivateKeySpec$vtype	_jc_java_security_spec_RSAPrivateKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_RSAPrivateKeySpec$method$_init$112bcad7f4f53827(_jc_env *, struct _jc_java_security_spec_RSAPrivateKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateKeySpec$method$getModulus$430be9ccecc735d2(_jc_env *, struct _jc_java_security_spec_RSAPrivateKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateKeySpec$method$getPrivateExponent$69e9ffb1613efb43(_jc_env *, struct _jc_java_security_spec_RSAPrivateKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_RSAPrivateKeySpec$method_info$getModulus$430be9ccecc735d2;
extern _jc_method _jc_java_security_spec_RSAPrivateKeySpec$method_info$getPrivateExponent$69e9ffb1613efb43;

// Virtual methods structure
struct _jc_java_security_spec_RSAPrivateKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getModulus$430be9ccecc735d2)(_jc_env *, struct _jc_java_security_spec_RSAPrivateKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getPrivateExponent$69e9ffb1613efb43)(_jc_env *, struct _jc_java_security_spec_RSAPrivateKeySpec$object *);
};

// Vtable
struct _jc_java_security_spec_RSAPrivateKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_RSAPrivateKeySpec$vmethods	java_security_spec_RSAPrivateKeySpec;
};

// Vtype
struct _jc_java_security_spec_RSAPrivateKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_RSAPrivateKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_RSAPrivateKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*modulus;
	struct _jc_java_math_BigInteger$object	*privateExponent;
};

// Reference instance fields (object)
struct _jc_java_security_spec_RSAPrivateKeySpec$refs {
    _jc_java_security_spec_RSAPrivateKeySpec$sub_refs	java_security_spec_RSAPrivateKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_RSAPrivateKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_RSAPrivateKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_RSAPrivateKeySpec$sub_nonrefs	java_security_spec_RSAPrivateKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_RSAPrivateKeySpec$object {
	_jc_java_security_spec_RSAPrivateKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_RSAPrivateKeySpec$vtype	*vtype;
	_jc_java_security_spec_RSAPrivateKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_RSAPrivateKeySpec$vtype _jc_java_security_spec_RSAPrivateKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_RSAPrivateKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_RSAPrivateKeySpec$class_object;

#endif	/* _JC_java_security_spec_RSAPrivateKeySpec_H_ */

==> jc-1.4.6.tar.gz: java/security/spec/RSAPrivateKeySpec.h <==
// public class java.security.spec.RSAPrivateKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 47d1dcfa807306d7 java_security_spec_RSAPrivateKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_RSAPrivateKeySpec_H_
#define _JC_java_security_spec_RSAPrivateKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_RSAPrivateKeySpec$sub_refs	_jc_java_security_spec_RSAPrivateKeySpec$sub_refs;
typedef struct _jc_java_security_spec_RSAPrivateKeySpec$sub_nonrefs	_jc_java_security_spec_RSAPrivateKeySpec$sub_nonrefs;
typedef struct _jc_java_security_spec_RSAPrivateKeySpec$refs	_jc_java_security_spec_RSAPrivateKeySpec$refs;
typedef struct _jc_java_security_spec_RSAPrivateKeySpec$nonrefs	_jc_java_security_spec_RSAPrivateKeySpec$nonrefs;
typedef struct _jc_java_security_spec_RSAPrivateKeySpec$object	_jc_java_security_spec_RSAPrivateKeySpec$object;

typedef const struct _jc_java_security_spec_RSAPrivateKeySpec$vmethods	_jc_java_security_spec_RSAPrivateKeySpec$vmethods;
typedef const struct _jc_java_security_spec_RSAPrivateKeySpec$vtable	_jc_java_security_spec_RSAPrivateKeySpec$vtable;
typedef const struct _jc_java_security_spec_RSAPrivateKeySpec$vtype	_jc_java_security_spec_RSAPrivateKeySpec$vtype;

// Constructors
extern void _jc_java_security_spec_RSAPrivateKeySpec$method$_init$112bcad7f4f53827(_jc_env *, struct _jc_java_security_spec_RSAPrivateKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateKeySpec$method$getModulus$430be9ccecc735d2(_jc_env *, struct _jc_java_security_spec_RSAPrivateKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_RSAPrivateKeySpec$method$getPrivateExponent$69e9ffb1613efb43(_jc_env *, struct _jc_java_security_spec_RSAPrivateKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_RSAPrivateKeySpec$method_info$getModulus$430be9ccecc735d2;
extern _jc_method _jc_java_security_spec_RSAPrivateKeySpec$method_info$getPrivateExponent$69e9ffb1613efb43;

// Virtual methods structure
struct _jc_java_security_spec_RSAPrivateKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getModulus$430be9ccecc735d2)(_jc_env *, struct _jc_java_security_spec_RSAPrivateKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getPrivateExponent$69e9ffb1613efb43)(_jc_env *, struct _jc_java_security_spec_RSAPrivateKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_spec_RSAPrivateKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_RSAPrivateKeySpec$vmethods	java_security_spec_RSAPrivateKeySpec;
};

// Vtype
struct _jc_java_security_spec_RSAPrivateKeySpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_RSAPrivateKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_RSAPrivateKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*modulus;
	struct _jc_java_math_BigInteger$object	*privateExponent;
};

// Reference instance fields (object)
struct _jc_java_security_spec_RSAPrivateKeySpec$refs {
    _jc_java_security_spec_RSAPrivateKeySpec$sub_refs	java_security_spec_RSAPrivateKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_RSAPrivateKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_RSAPrivateKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_RSAPrivateKeySpec$sub_nonrefs	java_security_spec_RSAPrivateKeySpec;
};

// Object instance structure
struct _jc_java_security_spec_RSAPrivateKeySpec$object {
	_jc_java_security_spec_RSAPrivateKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_RSAPrivateKeySpec$vtype	*vtype;
	_jc_java_security_spec_RSAPrivateKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_RSAPrivateKeySpec$vtype _jc_java_security_spec_RSAPrivateKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_RSAPrivateKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_RSAPrivateKeySpec$class_object;

#endif	/* _JC_java_security_spec_RSAPrivateKeySpec_H_ */
